@@ -6,7 +6,7 @@ import json
 import scipy.signal as sg
 from enum import Enum
 from typing import Dict, Optional, Tuple, Union, List
-from tdw.output_data import OutputData, Rigidbodies, Collision, EnvironmentCollision
+from tdw.output_data import OutputData, Rigidbodies, Collision, EnvironmentCollision, Robot
 from pathlib import Path
 from pkg_resources import resource_filename
 from csv import DictReader
@@ -382,6 +382,7 @@ class PyImpact:
 
         - You've already called `set_default_audio_info()` and supplied it with the IDs and names of each object in the scene:
         - You've requested collision and rigidbody data per-frame (`send_collisions` and `send_rigidbodies`)
+        - If there are robots in the scene, you've already requests robot data per-frame (`send_robots`)
 
         :param resp: The response from the build.
         :param floor: The floor material as an `AudioMaterial` enum value.
@@ -391,6 +392,15 @@ class PyImpact:
         :return: A list of commands that will play audio generated by the collisions on this frame. This can be empty.
         """
 
+        # Get all robot joints in the scene.
+        joint_ids = []
+        for i in range(len(resp) - 1):
+            r_id = OutputData.get_data_type_id(resp[i])
+            if r_id == "robo":
+                robo = Robot(resp[i])
+                for j in range(robo.get_num_joints()):
+                    joint_ids.append(robo.get_joint_id(j))
+
         commands = []
         collisions, env_collisions, rigidbodies = self.get_collisions(resp=resp)
         # Get the mass and speed of each object.
@@ -440,7 +450,8 @@ class PyImpact:
                                                           other_amp=other_audio.amp,
                                                           other_mat=other_audio.material.name + "_" + str(other_audio.size),
                                                           resonance=target_audio.resonance,
-                                                          play_audio_data=not resonance_audio))
+                                                          play_audio_data=not resonance_audio,
+                                                          robot_joints=joint_ids))
         # Play sounds from collisions with the environment.
         stays_and_exits.extend([c.get_object_id() for c in env_collisions if
                                 c.get_state() == "stay" or c.get_state() == "exit"])
@@ -628,7 +639,7 @@ class PyImpact:
         sound = amp * sound / np.max(np.abs(sound))
         return Base64Sound(sound)
 
-    def get_impact_sound_command(self, collision: Union[Collision, EnvironmentCollision], rigidbodies: Rigidbodies, target_id: int, target_mat: str, target_amp: float, other_id: int, other_mat: str, other_amp: float, resonance: float, play_audio_data: bool = True) -> dict:
+    def get_impact_sound_command(self, collision: Union[Collision, EnvironmentCollision], rigidbodies: Rigidbodies, target_id: int, target_mat: str, target_amp: float, other_id: int, other_mat: str, other_amp: float, resonance: float, play_audio_data: bool = True, robot_joints: List[int] = None) -> dict:
         """
         Create an impact sound, and return a valid command to play audio data in TDW.
         "target" should usually be the smaller object, which will play the sound.
@@ -644,6 +655,7 @@ class PyImpact:
         :param target_id: The ID of the object that will play the sound.
         :param resonance: The resonance of the objects.
         :param play_audio_data: If True, return a `play_audio_data` command. If False, return a `play_point_source_data` command (useful only with Resonance Audio; see Command API).
+        :param robot_joints: Optional; a list of robot joint IDs in the scene. Use this to correctly play audio day for a robot joint.
 
         :return A `play_audio_data` or `play_point_source_data` command that can be sent to the build via `Controller.communicate()`.
         """
@@ -656,6 +668,7 @@ class PyImpact:
                     "num_channels": 1,
                     "frame_rate": 44100,
                     "wav_data": impact_audio.wav_str,
+                    "robot_joint": robot_joints is not None and target_id in robot_joints,
                     "y_pos_offset": 0.1}
         # If PyImpact failed to generate a sound (which is rare!), fail silently here.
         else:
